## Version 0.3.3 (2025/03/27)


### Pull Requests Merged

#### Features added

* [PR 36](https://github.com/pytroll/pytroll-db/pull/36) - Update `deploy-sdist.yaml`

In this release 1 pull request was closed.


## Version 0.3.2 (2025/03/27)


### Pull Requests Merged

#### Bugs fixed

* [PR 17](https://github.com/pytroll/pytroll-db/pull/17) - Install `httpx` as a testing dependency in `ci.yml`

In this release 1 pull request was closed.


## Version 0.3.1 (2024/06/19)


### Pull Requests Merged

#### Features added

* [PR 9](https://github.com/pytroll/pytroll-db/pull/9) - Improve code coverage by adding more tests

In this release 1 pull request was closed.


## Version 0.3.0 (2024/05/31)


### Pull Requests Merged

#### Features added

* [PR 8](https://github.com/pytroll/pytroll-db/pull/8) - Add support for "dataset" messages
* [PR 6](https://github.com/pytroll/pytroll-db/pull/6) - Enhance code quality

In this release 2 pull requests were closed.


## Version 0.2.0 (2024/05/24)


### Pull Requests Merged

#### Bugs fixed

* [PR 5](https://github.com/pytroll/pytroll-db/pull/5) - Update node version.

#### Features added

* [PR 4](https://github.com/pytroll/pytroll-db/pull/4) - Fix conf.py for sphinx.
* [PR 2](https://github.com/pytroll/pytroll-db/pull/2) - Refactor with API

In this release 3 pull requests were closed.
